summaryrefslogtreecommitdiff
path: root/app/graphql/mutations/snippets/create.rb
diff options
context:
space:
mode:
Diffstat (limited to 'app/graphql/mutations/snippets/create.rb')
-rw-r--r--app/graphql/mutations/snippets/create.rb8
1 files changed, 4 insertions, 4 deletions
diff --git a/app/graphql/mutations/snippets/create.rb b/app/graphql/mutations/snippets/create.rb
index 89c21486a74..a068fd806f5 100644
--- a/app/graphql/mutations/snippets/create.rb
+++ b/app/graphql/mutations/snippets/create.rb
@@ -40,8 +40,8 @@ module Mutations
required: false,
description: 'The paths to files uploaded in the snippet description'
- argument :files, [Types::Snippets::FileInputType],
- description: "The snippet files to create",
+ argument :blob_actions, [Types::Snippets::BlobActionInputType],
+ description: 'Actions to perform over the snippet repository and blobs',
required: false
def resolve(args)
@@ -85,9 +85,9 @@ module Mutations
def create_params(args)
args.tap do |create_args|
# We need to rename `files` into `snippet_actions` because
# it's the expected key param
- create_args[:snippet_actions] = create_args.delete(:files)&.map(&:to_h)
+ create_args[:snippet_actions] = create_args.delete(:blob_actions)&.map(&:to_h)
# We need to rename `uploaded_files` into `files` because
# it's the expected key param
@@ -85,9 +85,9 @@ module Mutations
def create_params(args)
args.tap do |create_args|
- # We need to rename `files` into `snippet_actions` because
+ # We need to rename `blob_actions` into `snippet_actions` because
# it's the expected key param